import { world, system, BlockPermutation, GameMode } from "@minecraft/server";

world.beforeEvents.worldInitialize.subscribe(initEvent => {
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:corrupted_oak_sapling_growth", {
    onPlayerInteract: eventData => {
      const player = eventData.player;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      function decreaseItem () {
        if (!player.matches({ gameMode: GameMode.creative })) {
          const decrementItem = itemUsed.amount == 1 ? undefined : (itemUsed.amount--, itemUsed);
          playerEquippable.setEquipment("Mainhand", decrementItem)
        }
      }
      if (itemUsed === undefined) return;
      if (block.typeId === "nicothekid:corrupted_oak_sapling" && itemUsed.typeId === "minecraft:bone_meal") {
        system.run(() => {
          let randomChance = Math.random() * 100.0;
          decreaseItem ();
          block.dimension.playSound("item.bone_meal.use", blockLocation, { pitch: 1.0, volume: 1.0 });
          block.dimension.spawnParticle("minecraft:crop_growth_emitter", { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          if (randomChance <= 40.0) {
            let randomVariation = Math.random() * 100.0;
            if (randomVariation <= 20.0) {
              block.setPermutation(BlockPermutation.resolve("minecraft:air"));
              block.dimension.runCommandAsync(`structure load "mb/corrupted_oak_tree_small_01" ${blockLocation.x - 2} ${blockLocation.y - 1} ${blockLocation.z - 2}`);
            }
            else if (randomVariation <= 40.0) {
              block.setPermutation(BlockPermutation.resolve("minecraft:air"));
              block.dimension.runCommandAsync(`structure load "mb/corrupted_oak_tree_small_02" ${blockLocation.x - 2} ${blockLocation.y - 1} ${blockLocation.z - 2}`);
            }
            else if (randomVariation <= 60.0) {
              block.setPermutation(BlockPermutation.resolve("minecraft:air"));
              block.dimension.runCommandAsync(`structure load "mb/corrupted_oak_tree_small_03" ${blockLocation.x - 2} ${blockLocation.y - 1} ${blockLocation.z - 2}`);
            }
            else if (randomVariation <= 80.0) {
              block.setPermutation(BlockPermutation.resolve("minecraft:air"));
              block.dimension.runCommandAsync(`structure load "mb/corrupted_oak_tree_small_04" ${blockLocation.x - 2} ${blockLocation.y - 1} ${blockLocation.z - 2}`);
            }
            else if (randomVariation <= 100.0) {
              block.setPermutation(BlockPermutation.resolve("minecraft:air"));
              block.dimension.runCommandAsync(`structure load "mb/corrupted_oak_tree_large_01" ${blockLocation.x - 6} ${blockLocation.y - 1} ${blockLocation.z - 6}`);
            }
            else return;
          }
          else return;
        });
      }
      else return;
    }
  });
  initEvent.blockComponentRegistry.registerCustomComponent("nicothekid:corrupted_oak_sapling_on_player_destroy", {
    onPlayerDestroy: eventData => {
      const player = eventData.player;
      const destroyedBlock = eventData.destroyedBlockPermutation;
      const block = eventData.block;
      const blockLocation = block.location;
      const playerEquippable = player.getComponent("equippable");
      const itemUsed = playerEquippable.getEquipment("Mainhand");
      let randomChance = Math.random() * 100.0;
      if (player.matches({ gameMode: GameMode.creative })) return;
      if (destroyedBlock.type.id === "nicothekid:corrupted_oak_sapling_block") {
        if (itemUsed === undefined) {
          if (randomChance <= 10.0) {
            const spawnStick = new ItemStack ("minecraft:stick", 1);
            block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          }
          else return;
        }
        else {
          if (itemUsed.typeId === "minecraft:shears") {
            const spawnPlant = new ItemStack ("nicothekid:corrupted_oak_sapling", 1);
            block.dimension.spawnItem(spawnPlant, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
          }
          else {
            const itemEnchantable = itemUsed.getComponent("enchantable");
            if (itemEnchantable) {
              const silkTouchEnchanted = itemEnchantable.getEnchantment("silk_touch");
              if (silkTouchEnchanted) return;
              const fortuneEnchanted = itemUsed.getComponent("enchantable").getEnchantment("fortune");
              if (itemUsed.getComponent("enchantable").hasEnchantment("fortune")) {
                if (fortuneEnchanted.level == 1) {
                  if (randomChance <= 13.0) {
                    const spawnStick = new ItemStack ("minecraft:stick", 1);
                    block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
                  }
                  else return;
                }
                if (fortuneEnchanted.level == 2) {
                  if (randomChance <= 15.0) {
                    const spawnStick = new ItemStack ("minecraft:stick", 1);
                    block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
                  }
                  else return;
                }
                if (fortuneEnchanted.level == 3) {
                  if (randomChance <= 20.0) {
                    const spawnStick = new ItemStack ("minecraft:stick", 1);
                    block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
                  }
                  else return;
                }
              }
              else {
                if (randomChance <= 10.0) {
                  const spawnStick = new ItemStack ("minecraft:stick", 1);
                  block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
                }
                else return;
              }
            }
            else {
              if (randomChance <= 10.0) {
                const spawnStick = new ItemStack ("minecraft:stick", 1);
                block.dimension.spawnItem(spawnStick, { x: blockLocation.x + 0.5, y: blockLocation.y + 0.5, z: blockLocation.z + 0.5 });
              }
              else return;
            }
          }
        }
      }
      else return;
    }
  });
});
