import { world, system, BlockPermutation, ItemStack, GameMode } from "@minecraft/server";

world.beforeEvents.itemUseOn.subscribe(eventData => {
  const player = eventData.source;
  const itemUsed = eventData.itemStack;
  const block = eventData.block;
  const blockLocation = block.location;
  const playerEquippable = player.getComponent("equippable");
  const stateAll = block.permutation.getAllStates();
  function damageDurability () {
    if (!player.matches({ gameMode: GameMode.creative })) {
      const itemEnchantable = itemUsed.getComponent("minecraft:enchantable");
      const unbreakingLevel = itemEnchantable?.getEnchantment("unbreaking")?.level ?? 0;
      const breakChance = 100 / (unbreakingLevel + 1);
      const randomizeChance = Math.random() * 100;
      if (breakChance < randomizeChance) return;
      const itemDurability = itemUsed.getComponent("durability");
      if (!itemDurability) return;
      const itemMaxDurability = itemDurability.maxDurability;
      const itemDurabilityDamage = itemDurability.damage;
      const durabilityCalculation = itemMaxDurability - itemDurabilityDamage;
      let damageAmount = 1;
      const currentDurability = durabilityCalculation - damageAmount;
      if (currentDurability <= 0) {
        player.playSound("random.break", { pitch: 0.9, location: player.location, volume: 1 });
        playerEquippable.setEquipment("Mainhand", null);
      }
      else {
        itemDurability.damage += damageAmount;
        playerEquippable.setEquipment("Mainhand", itemUsed)
      }
    }
  }
  if (itemUsed === undefined) return;
  if (itemUsed.hasTag("minecraft:is_axe") || itemUsed.hasTag("minecraft:is_hoe")) {
    if (itemUsed.hasTag("minecraft:is_axe")) {
      const customWoods = [
        "nicothekid:corrupted_oak_log",
        "nicothekid:corrupted_oak_wood",
        "nicothekid:mossy_willow_log",
        "nicothekid:mossy_willow_wood",
        "nicothekid:overgrown_jungle_log",
        "nicothekid:overgrown_jungle_wood"
      ]
      if (customWoods.includes(block.typeId)) {
        system.run(() => {
          damageDurability ();
          if (block.permutation.matches("nicothekid:corrupted_oak_log")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_corrupted_oak_log", stateAll ));
            return;
          }
          if (block.permutation.matches("nicothekid:corrupted_oak_wood")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_corrupted_oak_wood", stateAll ));
            return;
          }
          if (block.permutation.matches("nicothekid:mossy_willow_log")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_mossy_willow_log", stateAll ));
            return;
          }
          if (block.permutation.matches("nicothekid:mossy_willow_wood")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_mossy_willow_wood", stateAll ));
            return;
          }
          if (block.permutation.matches("nicothekid:overgrown_jungle_log")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_overgrown_jungle_log", stateAll ));
            return;
          }
          if (block.permutation.matches("nicothekid:overgrown_jungle_wood")) {
            block.dimension.playSound("use.wood", blockLocation, { pitch: 0.8, volume: 1.0 });
            block.setPermutation(BlockPermutation.resolve("nicothekid:stripped_overgrown_jungle_wood", stateAll ));
            return;
          }
        });
      }
    }
    if (itemUsed.hasTag("minecraft:is_hoe")) {
      const mossedBlocks = [
        "nicothekid:mossed_corrupted_oak_log_side",
        "nicothekid:mossed_corrupted_oak_log_top",
        "nicothekid:mossed_mossy_willow_log_side",
        "nicothekid:mossed_mossy_willow_log_top",
        "nicothekid:mossed_overgrown_jungle_log_side",
        "nicothekid:mossed_overgrown_jungle_log_top"
      ]
      if (mossedBlocks.includes(block.typeId)) {
        system.run(() => {
          const pitchRange = Math.random() * (1.0 - 0.8) + 0.8;
          function spawnMossCarpet () {
            const mossCarpet = new ItemStack ("minecraft:moss_carpet", 1);
            let randomChance = Math.random();
            if (itemUsed.getComponent("enchantable").hasEnchantment("silk_touch")) {
              block.dimension.spawnItem(mossCarpet, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
            }
            else if (itemUsed.getComponent("enchantable").hasEnchantment("fortune")) {
              if (itemUsed.getComponent("enchantable").getEnchantment("fortune").level == 1) {
                if (randomChance <= 0.5) {
                  block.dimension.spawnItem(mossCarpet, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
                }
              }
              if (itemUsed.getComponent("enchantable").getEnchantment("fortune").level == 2) {
                if (randomChance <= 0.75) {
                  block.dimension.spawnItem(mossCarpet, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
                }
              }
              if (itemUsed.getComponent("enchantable").getEnchantment("fortune").level == 3) {
                if (randomChance <= 1.0) {
                  block.dimension.spawnItem(mossCarpet, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
                }
              }
            }
            else {
              if (randomChance <= 0.25) {
                block.dimension.spawnItem(mossCarpet, { x: blockLocation.x + 0.5, y: blockLocation.y + 1.0, z: blockLocation.z + 0.5 });
              }
              else return;
            }
          }
          damageDurability ();
          spawnMossCarpet ();
          block.dimension.playSound("use.gravel", blockLocation, { pitch: pitchRange, volume: 0.8 });
          if (block.permutation.matches("nicothekid:mossed_corrupted_oak_log_side")) {
            const stateCardinalDirection = block.permutation.getState("minecraft:cardinal_direction");
            block.setPermutation(BlockPermutation.resolve("nicothekid:corrupted_oak_log", { "minecraft:block_face": stateCardinalDirection }));
          }
          if (block.permutation.matches("nicothekid:mossed_corrupted_oak_log_top")) {
            block.setPermutation(BlockPermutation.resolve("nicothekid:corrupted_oak_log"));
          }
          if (block.permutation.matches("nicothekid:mossed_mossy_willow_log_side")) {
            const stateCardinalDirection = block.permutation.getState("minecraft:cardinal_direction");
            block.setPermutation(BlockPermutation.resolve("nicothekid:mossy_willow_log", { "minecraft:block_face": stateCardinalDirection }));
          }
          if (block.permutation.matches("nicothekid:mossed_mossy_willow_log_top")) {
            block.setPermutation(BlockPermutation.resolve("nicothekid:mossy_willow_log"));
          }
          if (block.permutation.matches("nicothekid:mossed_overgrown_jungle_log_side")) {
            const stateCardinalDirection = block.permutation.getState("minecraft:cardinal_direction");
            block.setPermutation(BlockPermutation.resolve("nicothekid:overgrown_jungle_log", { "minecraft:block_face": stateCardinalDirection }));
          }
          if (block.permutation.matches("nicothekid:mossed_overgrown_jungle_log_top")) {
            block.setPermutation(BlockPermutation.resolve("nicothekid:overgrown_jungle_log"));
          }
        });
      }
    }
  }
  else return;
});
